==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/hu_HU.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumentumok",
    "Can't create document" : "A dokumentum nem hozható létre",
    "You don't have permission to rename this document" : "Nincs joga ahhoz, hogy átnevezze ezt a dokumentumot",
    "Directory saved successfully." : "A mappát sikeresen elmentettük.",
    "An error occurred while changing directory." : "Hiba történt a másik mappára történő áttérés közben.",
    "Saved" : "Elmentve",
    "Format filter server is down or misconfigured" : "A formátumszűrő szerver nem üzemel, vagy rosszul van konfigurálva",
    "Conversion failed. Check log for details." : "Az átalakítás nem sikerült. Ellenőrizze a naplóállományban a részleteket!",
    "Saving..." : "Mentés...",
    "Failed to load documents." : "A dokumentum betőltése sikertelen",
    "No documents were found. Upload or create a document to get started!" : "Itt nincs semmi. Töltsön fel, vagy hozzon létre egy dokumentumot!",
    "No connection to server. Trying to reconnect." : "Nincs kapcsolat a kiszolgálóval. Újra próbálunk csatlakozni.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Ha elhagyja ezt az oldalt, miközben Szerkesztés módban van, akkor előfordulhat, hogy nem minden adat mentődik el. Érdemes inkább a 'Bezár' gombbal befejezni az oldal szerkesztését.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "A dokumentum betöltése sikertelen. Próbálja külső odt szerkeszővel megnyitni. Ez hiba jelentheti azt is, hogy már nincs megosztva, vagy már törölve lett a dokumentum.",
    "Save" : "Mentés",
    "Loading documents..." : "Dokumentumok betöltése...",
    "'.' is an invalid file name." : "'.' érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Érvénytelen elnevezés. Ezek a karakterek nem használhatók: '\\', '/', '<', '>', ':', '\"', '|', '?' és '*'",
    "Align Left" : "Balra igazítás",
    "Alignment" : "Igazítás",
    "Align Right" : "Jobbra igazítás",
    "Annotate" : "Megjegyzés beírása",
    "Background" : "Háttér",
    "Bold" : "Félkövér",
    "Bottom" : "Alsó",
    "Cancel" : "Mégsem",
    "Center" : "Közép",
    "Clone" : "Másolás",
    "Clone this Style" : "Stílus másolása",
    "Close" : "Bezárás",
    "Color" : "Szín",
    "Create" : "Létrehozás",
    "Decrease Indent" : "Bekezdés csökkentése",
    "Default Style" : "Alapértelmezett stílus",
    "Delete" : "Törlés",
    "Family" : "Család",
    "Font" : "Betűtípus",
    "Font Effects" : "Betűtípus-hatások",
    "Format" : "Formátum",
    "Increase Indent" : "Bekezdés növelése",
    "Insert Image" : "Kép beillesztése",
    "Invite Members" : "Együttműködők meghívása",
    "Italic" : "Dőlt",
    "Justified" : "Sorkizárt",
    "Justify" : "Sorkizár",
    "Left" : "Bal",
    "Loading" : "Betöltés",
    "Members" : "Együttműködők",
    "New Name:" : "Új név:",
    "OK" : "OK",
    "Open" : "Megnyitás",
    "Options" : "Opciók",
    "Paragraph..." : "Bekezdés...",
    "Paragraph Styles" : "Bekezdés stílusok",
    "Redo" : "Mégse vonjuk vissza",
    "Right" : "Jobb",
    "Size" : "Méret",
    "Spacing" : "Ritkítás",
    "Strikethrough" : "Áthúzott",
    "Style" : "Stílus",
    "Text" : "szöveg",
    "Top" : "Felső",
    "Underline" : "Aláhúzás",
    "Undo" : "Visszavonás",
    "Unknown Author" : "Ismeretlen szerző",
    "Edit" : "Szerkesztés",
    "Share" : "Megosztás",
    "guest" : "vendég",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word támogatás (openOffice/libreOffice-t igényel)",
    "Local" : "Helyi",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "Az openOffice/libreOffice telepítve van ezen a kiszolgálón. A program elérési útvonala a config.php  preview_libreoffice_path paraméterében adható meg.",
    "External" : "Külső",
    "openOffice/libreOffice is installed on external server running a format filter server" : "Az openOffice/libreOffice egy másik kiszolgálón van telepítve, ott zajlik a formátum átalakítása",
    "Disabled" : "Kikapcsolva",
    "No MS Word support" : "Nincs MS Word-támogatás",
    "scheme://domain.tld[:port]" : "protokoll://teljes.gép.név[:port]",
    "Server URL" : "Szerver URL",
    "Apply and test" : "A beállítás kipróbálása",
    "New document" : "Új dokumentum",
    "Upload (max. %s)" : "Feltöltés (max. %s)",
    "Upload" : "Feltöltés",
    "Save new documents to" : "Az új dokumentumokat ide mentse:",
    "Wrong password. Please retry." : "Hibás jelszó. Próbálkozzon újra!",
    "Password" : "Jelszó",
    "Guest %s" : "Vendég: %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ez a link vagy lejárt vagy sohasem létezett. Kérdezze meg azt, aki megosztotta Önnel ezt a linket.",
    "Advanced feature-set" : "Haladó funkciók",
    "(Unstable)" : "(nem stabil)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/hu_HU.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumentumok",
    "Can't create document" : "A dokumentum nem hozható létre",
    "You don't have permission to rename this document" : "Nincs joga ahhoz, hogy átnevezze ezt a dokumentumot",
    "File does not exist" : "A fájl nem létezik!",
    "Directory saved successfully." : "A mappát sikeresen elmentettük.",
    "An error occurred while changing directory." : "Hiba történt a másik mappára történő áttérés közben.",
    "Saved" : "Elmentve!",
    "Format filter server is down or misconfigured" : "A formátumszűrő szerver nem üzemel, vagy rosszul van konfigurálva",
    "Conversion failed. Check log for details." : "Az átalakítás nem sikerült. Ellenőrizze a naplóállományban a részleteket!",
    "Saving..." : "Mentés...",
    "Failed to load documents." : "A dokumentum betőltése sikertelen",
    "No documents were found. Upload or create a document to get started!" : "Itt nincs semmi. Töltsön fel, vagy hozzon létre egy dokumentumot!",
    "No connection to server. Trying to reconnect." : "Nincs kapcsolat a kiszolgálóval. Újra próbálunk csatlakozni.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Ha elhagyja ezt az oldalt, miközben Szerkesztés módban van, akkor előfordulhat, hogy nem minden adat mentődik el. Érdemes inkább a 'Bezár' gombbal befejezni az oldal szerkesztését.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "A dokumentum betöltése sikertelen. Próbálja külső odt szerkeszővel megnyitni. Ez hiba jelentheti azt is, hogy már nincs megosztva, vagy már törölve lett a dokumentum.",
    "Save" : "Mentés",
    "Loading documents..." : "Dokumentumok betöltése...",
    "'.' is an invalid file name." : "'.' érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet üres.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Érvénytelen elnevezés. Ezek a karakterek nem használhatók: '\\', '/', '<', '>', ':', '\"', '|', '?' és '*'",
    "Align Left" : "Balra igazítás",
    "Alignment" : "Igazítás",
    "Align Right" : "Jobbra igazítás",
    "Annotate" : "Megjegyzés beírása",
    "Background" : "Háttér",
    "Bold" : "Félkövér",
    "Bottom" : "Alsó",
    "Cancel" : "Mégsem",
    "Center" : "Közép",
    "Clone" : "Másolás",
    "Clone this Style" : "Stílus másolása",
    "Close" : "Bezárás",
    "Color" : "Szín",
    "Create" : "Létrehozás",
    "Decrease Indent" : "Bekezdés csökkentése",
    "Default Style" : "Alapértelmezett stílus",
    "Delete" : "Törlés",
    "Family" : "Család",
    "Font" : "Betűtípus",
    "Font Effects" : "Betűtípus-hatások",
    "Format" : "Formátum",
    "Increase Indent" : "Bekezdés növelése",
    "Insert Image" : "Kép beillesztése",
    "Invite Members" : "Együttműködők meghívása",
    "Italic" : "Dőlt",
    "Justified" : "Sorkizárt",
    "Justify" : "Sorkizár",
    "Left" : "Bal",
    "Loading" : "Betöltés",
    "Members" : "Együttműködők",
    "New Name:" : "Új név:",
    "OK" : "OK",
    "Open" : "Megnyitás",
    "Options" : "Opciók",
    "Paragraph..." : "Bekezdés...",
    "Paragraph Styles" : "Bekezdés stílusok",
    "Redo" : "Mégse vonjuk vissza",
    "Right" : "Jobb",
    "Size" : "Méret",
    "Spacing" : "Ritkítás",
    "Strikethrough" : "Áthúzott",
    "Style" : "Stílus",
    "Text" : "szöveg",
    "Top" : "Felső",
    "Underline" : "Aláhúzás",
    "Undo" : "Visszavonás",
    "Unknown Author" : "Ismeretlen szerző",
    "Shared" : "Megosztott",
    "Error" : "Hiba",
    "Error while sharing" : "Nem sikerült létrehozni a megosztást",
    "Error while unsharing" : "Nem sikerült visszavonni a megosztást",
    "Error while changing permissions" : "Nem sikerült módosítani a jogosultságokat",
    "Shared with you and the group {group} by {owner}" : "Megosztotta Önnel és a(z) {group} csoporttal: {owner}",
    "Shared with you by {owner}" : "Megosztotta Önnel: {owner}",
    "Share with users or groups …" : "Megosztás felhasználókkal vagy csoportokkal ...",
    "Share with users, groups or remote users …" : "Megosztás felhasználókkal, csoportokkal vagy távoli felhasználókkal ...",
    "Share" : "Megosztás",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Megosztás más ownCloud szerverekkel, a következő formátum használatával felhasznalo@példa.com/owncloud",
    "Share link" : "Megosztás hivatkozással",
    "The public link will expire no later than {days} days after it is created" : "A nyilvános link érvényessége legkorábban {days} nappal a létrehozása után jár csak le",
    "Link" : "Link",
    "Password protect" : "Jelszóval is védem",
    "Password" : "Jelszó",
    "Choose a password for the public link" : "Válasszon egy jelszót a nyilvános linkhez",
    "Allow editing" : "Szerkesztés engedélyezése",
    "Email link to person" : "Email címre küldjük el",
    "Send" : "Küldjük el",
    "Set expiration date" : "Legyen lejárati idő",
    "Expiration" : "Lejárat",
    "Expiration date" : "A lejárati idő",
    "An error occured. Please try again" : "Hiba történt. Kérjük, próbáld újra!",
    "Adding user..." : "Felhasználó hozzáadása...",
    "group" : "csoport",
    "remote" : "távoli",
    "Resharing is not allowed" : "Ezt az állományt csak a tulajdonosa oszthatja meg másokkal",
    "Shared in {item} with {user}" : "Megosztva {item}-ben {user}-rel",
    "Unshare" : "A megosztás visszavonása",
    "notify by email" : "e-mail értesítés",
    "can share" : "megosztható",
    "can edit" : "módosíthat",
    "access control" : "jogosultság",
    "create" : "létrehoz",
    "change" : "változtatás",
    "delete" : "törlés",
    "Password protected" : "Jelszóval van védve",
    "Error unsetting expiration date" : "Nem sikerült a lejárati időt törölni",
    "Error setting expiration date" : "Nem sikerült a lejárati időt beállítani",
    "Sending ..." : "Küldés ...",
    "Email sent" : "Az e-mail elküldve!",
    "Warning" : "Figyelmeztetés",
    "Edit" : "Szerkesztés",
    "guest" : "vendég",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word támogatás (openOffice/libreOffice-t igényel)",
    "Local" : "Helyi",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "Az openOffice/libreOffice telepítve van ezen a kiszolgálón. A program elérési útvonala a config.php  preview_libreoffice_path paraméterében adható meg.",
    "External" : "Külső",
    "openOffice/libreOffice is installed on external server running a format filter server" : "Az openOffice/libreOffice egy másik kiszolgálón van telepítve, ott zajlik a formátum átalakítása",
    "Disabled" : "Kikapcsolva",
    "No MS Word support" : "Nincs MS Word-támogatás",
    "scheme://domain.tld[:port]" : "protokoll://teljes.gép.név[:port]",
    "Server URL" : "Szerver URL",
    "Apply and test" : "A beállítás kipróbálása",
    "New document" : "Új dokumentum",
    "Upload (max. %s)" : "Feltöltés (max. %s)",
    "Upload" : "Feltöltés",
    "Save new documents to" : "Az új dokumentumokat ide mentse:",
    "Wrong password. Please retry." : "Hibás jelszó. Próbálkozzon újra!",
    "Guest %s" : "Vendég: %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ez a link vagy lejárt vagy sohasem létezett. Kérdezze meg azt, aki megosztotta Önnel ezt a linket.",
    "Advanced feature-set" : "Haladó funkciók",
    "(Unstable)" : "(nem stabil)"
},
"nplurals=2; plural=(n != 1);");
